@@ -162,6 +162,18 @@ class Moji:
             '_SessionToken': cls._SessionToken,
         }).json()
 
+    @classmethod
+    def fetch_word(cls, object_id: str) -> dict:
+        return utils.request_post('https://api.mojidict.com/parse/functions/ui-union-apis-word', headers={
+            'X-Parse-Application-Id': cls._ApplicationId,
+        }, json={
+            'skipAccessories': False,
+            'objectId': object_id,
+            'g_os': 'iOS',
+            'isVerb3': True,
+            'g_ver': '6.28.2',
+        }).json()
+
     @classmethod
     def fetch_words(cls, *object_ids: str) -> dict:
         """
